==> c3p0-0.9.5-pre3-sources.jar: com/mchange/v2/c3p0/AbstractConnectionCustomizer.java <==
/*
 * Distributed as part of c3p0 v.0.9.5-pre3
 *
 * Copyright (C) 2013 Machinery For Change, Inc.
 *
 * Author: Steve Waldman <swaldman@mchange.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of EITHER:
 *
 *     1) The GNU Lesser General Public License (LGPL), version 2.1, as 
 *        published by the Free Software Foundation
 *
 * OR
 *
 *     2) The Eclipse Public License (EPL), version 1.0
 *
 * You may choose which license to accept if you wish to redistribute
 * or modify this work. You may offer derivatives of this work
 * under the license you have chosen, or you may provide the same
 * choice of license which you have been offered here.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * You should have received copies of both LGPL v2.1 and EPL v1.0
 * along with this software; see the files LICENSE-EPL and LICENSE-LGPL.
 * If not, the text of these licenses are currently available at
 *
 * LGPL v2.1: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 *  EPL v1.0: http://www.eclipse.org/org/documents/epl-v10.php 
 * 
 */

package com.mchange.v2.c3p0;

import java.sql.Connection;
import java.sql.SQLException;

/**
 *  An abstract implementation of the
 *  ConnectionCustomizer interface
 *  in which all methods are no-ops.
 *
 *  Just a convenience class since
 *  most clients will only need to
 *  implement a single method.
 */
public abstract class AbstractConnectionCustomizer implements ConnectionCustomizer
{
    public void onAcquire( Connection c, String parentDataSourceIdentityToken ) throws Exception
    {}

    public void onDestroy( Connection c, String parentDataSourceIdentityToken  ) throws Exception
    {}

    public void onCheckOut( Connection c, String parentDataSourceIdentityToken  ) throws Exception
    {}

    public void onCheckIn( Connection c, String parentDataSourceIdentityToken  ) throws Exception
    {}
}

==> c3p0-0.9.5.1-sources.jar: com/mchange/v2/c3p0/AbstractConnectionCustomizer.java <==
/*
 * Distributed as part of c3p0 v.0.9.5.1
 *
 * Copyright (C) 2015 Machinery For Change, Inc.
 *
 * Author: Steve Waldman <swaldman@mchange.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of EITHER:
 *
 *     1) The GNU Lesser General Public License (LGPL), version 2.1, as 
 *        published by the Free Software Foundation
 *
 * OR
 *
 *     2) The Eclipse Public License (EPL), version 1.0
 *
 * You may choose which license to accept if you wish to redistribute
 * or modify this work. You may offer derivatives of this work
 * under the license you have chosen, or you may provide the same
 * choice of license which you have been offered here.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * You should have received copies of both LGPL v2.1 and EPL v1.0
 * along with this software; see the files LICENSE-EPL and LICENSE-LGPL.
 * If not, the text of these licenses are currently available at
 *
 * LGPL v2.1: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 *  EPL v1.0: http://www.eclipse.org/org/documents/epl-v10.php 
 * 
 */

package com.mchange.v2.c3p0;

import java.util.Map;
import java.sql.Connection;
import java.sql.SQLException;

/**
 *  An abstract implementation of the
 *  ConnectionCustomizer interface
 *  in which all methods are no-ops.
 *
 *  Just a convenience class since
 *  most clients will only need to
 *  implement a single method.
 */
public abstract class AbstractConnectionCustomizer implements ConnectionCustomizer
{
    protected Map extensionsForToken( String parentDataSourceIdentityToken )
    { return C3P0Registry.extensionsForToken( parentDataSourceIdentityToken ); }

    public void onAcquire( Connection c, String parentDataSourceIdentityToken ) throws Exception
    {}

    public void onDestroy( Connection c, String parentDataSourceIdentityToken  ) throws Exception
    {}

    public void onCheckOut( Connection c, String parentDataSourceIdentityToken  ) throws Exception
    {}

    public void onCheckIn( Connection c, String parentDataSourceIdentityToken  ) throws Exception
    {}
}
